PatternBasedSuggest

Struct PatternBasedSuggest 

pub struct PatternBasedSuggest { /* private fields */ }
Adapter: Rule → Suggest trait

Wraps a ryo-pattern Rule and implements the Suggest trait, enabling pattern-based lint rules to integrate with the suggestion system.

Example

use ryo_suggest::pattern::{RuleStore, PatternBasedSuggest};

let store = RuleStore::builtin_only()?;
for rule in store.all_rules() {
    let suggest = PatternBasedSuggest::new(rule.clone());
    registry.register(Box::new(suggest));
}

Implementations

Source

impl PatternBasedSuggest

pub fn new(rule: Rule) -> Self

Create a new PatternBasedSuggest from a Rule

pub fn rule(&self) -> &Rule

Get the underlying rule